/**
  Copyright (C) 2000 Helsinki University of Technology, Inc. All rights Reserved.
  XXX   %Z%%M% version %I% date:%G%
  Component:  ECDSAPrivateKeySpec
  Package: fi.hut.tcm.ECImplementation
  File:    ECDSAPrivateKeySpec.java
*/

package fi.hut.tcm.tessa.ECImplementation;

import java.math.BigInteger;

import fi.hut.tcm.tessa.ECInterfaces.*;


/**
 * This class specifies a ECDSA private key with its associated parameters.
 *
 */

public class ECDSAPrivateKeySpec implements java.security.spec.KeySpec {

    private ECDSAParams curve;
    private BigInteger d;

    /**
     * Creates a new ECDSAPrivateKeySpec with the specified parameter values.
     * 
     */
    public ECDSAPrivateKeySpec(byte[] privateKey) {
		byte length = privateKey[0];
		byte[] curve = new byte[length];
		System.arraycopy(privateKey, 1, curve, 0, length);
		byte[] key = new byte[privateKey.length - length -1];
		System.arraycopy(privateKey, 1 + length, key, 0, privateKey.length - length -1);
		this.curve = ECDSACurve.getStandardCurve(curve);
		this.d = ((ECDSACurve)this.curve).OS2I(key);
    }


	public ECDSAPrivateKeySpec(ECDSAParams curve, BigInteger d) {
		this.curve = curve;
		this.d = d;
	}

    /**
     * Returns the parameters used (the curve).
     *
     */
    public ECDSAParams getParams() {
	return this.curve;
    }


    /**
     * Returns the private key.
     *
	*/
    public BigInteger getD() {
	return this.d;
    }

}
