/**
  Copyright (C) 2000 Helsinki University of Technology, Inc. All rights Reserved.
  XXX   %Z%%M% version %I% date:%G%
  Component:  ECDSAPublicKeySpec
  Package: fi.hut.tcm.ECImplementation
  File:    ECDSAPublicKeySpec.java
*/
package fi.hut.tcm.tessa.ECImplementation;

import java.math.BigInteger;
import fi.hut.tcm.tessa.ECInterfaces.*;



/**
 * This class specifies an ECDSA public key with its associated parameters.
 */

public class ECDSAPublicKeySpec implements java.security.spec.KeySpec {

    private ECDSAParams curve;
    private ECPoint q;

    /**
     * Creates a new ECDSAPublicKeySpec with the specified parameter values.
     * 
     * @param curve the elliptic curve.
     * 
     * @param q the public key.
     */
    public ECDSAPublicKeySpec(byte[] publicKey) {
		byte length = publicKey[0];
		byte[] curve = new byte[length];
		System.arraycopy(publicKey, 1, curve, 0, length);
		byte[] key = new byte[publicKey.length - length -1];
		System.arraycopy(publicKey, 1 + length, key, 0, publicKey.length - length -1);
		this.curve = ECDSACurve.getStandardCurve(curve);
		this.q = ((ECDSACurve)this.curve).OS2P(key);
    }



    /**
     * Creates a new ECDSAPublicKeySpec with the specified parameter values.
     * 
     * @param curve the elliptic curve.
     * 
     * @param q the public key.
     */
	public ECDSAPublicKeySpec(ECDSAParams curve, ECPoint q) {
		this.curve = curve;
		this.q = q;
	}


    /**
     * Returns the public key <code>Q</code>.
     *
     * @return the public key <code>y</code>.
     */
    public ECPoint getQ() {
	return this.q;
    }


    /**
     * Returns the elliptic curve.
     *
     * @return the elliptic curve.
     */
    public ECDSAParams getParams() {
	return this.curve;
    }

}
