/**
  Copyright (C) 2000 Helsinki University of Technology, Inc. All rights Reserved.
  XXX   %Z%%M% version %I% date:%G%
  Component:  ECProvider
  Package: fi.hut.tcm.ECImplementation
  File:    ECProvider.java
*/

package fi.hut.tcm.tessa.ECImplementation;
import fi.hut.tcm.tessa.ECInterfaces.*;
import java.math.BigInteger;
import java.security.*;
import java.io.*;
import java.security.spec.*;


/**
  ECProvider
  
  Used to register the ECDSA functionality to the Java Runtime Environment.
*/
public final class ECProvider
  extends Provider {

  /**
    @doc
    A description of the provider and its services.
    
   */
  private String info = "TeSSA.tcm.hut.fi ECProvider v. 0.1, implements ECDSA signing with parameter and key generation";
  
  /**
    @doc
    The provider version number.
  */
  private double version = 0.1;
  
  /**
    @doc
    The provider name.
  */
  private String name = "TeSSA.tcm.hut.fi ECProvider";
  
  /**
	@doc
    The default constructor that registers the ECDSA functionality to the Java Runtime Environment.
  */
  public ECProvider() {
  //+ ECProvider::ECProvider( )
	super("TeSSA.tcm.hut.fi ECProvider v. 0.1, implements ECDSA signing with parameter and key generation",
		 0.1, "TeSSA.tcm.hut.fi ECProvider");

	AccessController.doPrivileged(new java.security.PrivilegedAction() {
		public Object run() {
			put("Signature.ECDSA", "fi.hut.tcm.tessa.ECImplementation.ECDSASignature");
			put("KeyPairGenerator.ECDSA", "fi.hut.tcm.tessa.ECImplementation.ECDSAKeyPairGenerator");
			put("AlgorithmParameters.ECDSA", "fi.hut.tcm.tessa.ECImplementation.ECDSACurve");
			put("KeyFactory.ECDSA", "fi.hut.tcm.tessa.ECImplementation.ECDSAKeyFactory");
			return null;
		};
	});
  //- ECProvider::ECProvider( )
  }
  
  /**
    @doc
    Returns the name of this provider.
    
    @return the name of this provider.
  */
  public final String getName() {
	return name;
  }
  
  /**
    @doc
    Returns the version number for this provider.
    
    @return the version number for this provider.
  */
  public final double getVersion() {
	return version;
  }
  
  /**
	@doc
	Returns information about this provider.
	
	@return Information about this provider.
  */
  public String getInfo() {
	return info;
  }
  
  /**
    @doc
    Returns a string with the name and the version number
    of this provider.
    
    @return the string with the name and the version number
    for this provider.
  */
  public final String toString() {
	return info;
  }
  
  /**
    
         * override 3 methods from Hashtable to ensure that provider
         * information can only be changed if the caller has the 
    appropriate
         * permissions.
         
    @doc
    Clears this provider so that it no longer contains the properties
    used to look up facilities implemented by the provider.
    
    @since JDK1.2
  */
  public final void clear() {
  }
  
  /**
  */
  private static final void check(String directive) {
  }
  
  /**
  */
  private static final void debug(String msg) {
  }
  
  /**
  */
  private static final void debug(String msg, Throwable t) {
  }
  
} // ECProvider
