/**
  Copyright (C) 2000 Helsinki University of Technology, Inc. All rights Reserved.
  XXX   %Z%%M% version %I% date:%G%
  Component:  ECUtilities
  Package: fi.hut.tcm.ECImplementation
  File:    ECUtilities.java
*/

package fi.hut.tcm.tessa.ECImplementation;
import fi.hut.tcm.tessa.ECInterfaces.*;
import java.math.BigInteger;
import java.security.*;
import java.io.*;
import java.security.spec.*;

/**
  ECUtilities
  
  A utility class containing constants and a method for calculating
  modulo square roots.  
*/
class ECUtilities
  extends Object {

  /**
  */
  static BigInteger TWO = new BigInteger("2");;
  
  /**
  */
  static BigInteger THREE = new BigInteger("3");;
  
  /**
  */
  static BigInteger FOUR = new BigInteger("4");;
  
  /**
  */
  static BigInteger FIVE = new BigInteger("5");;
  
  /**
  */
  static BigInteger EIGHT = new BigInteger("8");;
  
  /**
    @doc
    Application-specified source of randomness. 
  */
  private static SecureRandom appRandom;
  
  /**
  */
  public static BigInteger modSqrt(BigInteger g, BigInteger P) {
	if (P.mod(FOUR).compareTo(THREE) == 0) {
		BigInteger u = P.subtract(THREE).divide(FOUR);
		BigInteger y = g.modPow(u.add(BigInteger.ONE), P);
		BigInteger z = y.multiply(y).mod(P);
		if (g.compareTo(z) == 0) {
			return y;
		} else {
			return null;
		}
	} else if (P.mod(EIGHT).compareTo(FIVE) == 0) {
		BigInteger u = P.subtract(FIVE).divide(EIGHT);
		BigInteger t = g.multiply(TWO).modPow(u, P);
		BigInteger i = t.multiply(t).multiply(TWO).multiply(g).mod(P);
		BigInteger y = g.multiply(t).multiply(i.subtract(BigInteger.ONE)).mod(P);
		BigInteger z = y.multiply(y).mod(P);
		if (y.compareTo(z) == 0) {
			return y;
		} else {
			return null;
		}
	} else if (P.mod(FOUR).compareTo(BigInteger.ONE) == 0) {
		BigInteger u = P.subtract(BigInteger.ONE).divide(FOUR);
		BigInteger Q = g;

		while (true) {
			BigInteger B = new BigInteger(P.bitLength(), appRandom).mod(P);
			LucasSequence ls = LucasSequence.generate(P, B, Q, u.multiply(TWO).add(BigInteger.ONE));
			if (ls.getU().compareTo(BigInteger.ZERO) == 0) {
				return ls.getV().divide(TWO).mod(P);
			}
			if (ls.getV().compareTo(BigInteger.ZERO) == 0) {
				return null;
			}
		}
	} else {
		throw new RuntimeException("XXX You are not supposed to be here...");
	}
  }
  


  /**
	A static constructor that initialises the SecureRandom used.

  */
  static {
	try {
		appRandom = SecureRandom.getInstance("SHA1PRNG");
	} catch (NoSuchAlgorithmException e) {
		throw new RuntimeException("XXX");
	}
  }
  
} // ECUtilities
