/**
  Copyright (C) 2000 Helsinki University of Technology, Inc. All rights Reserved.
  XXX   %Z%%M% version %I% date:%G%
  Component:  LucasSequence
  Package: fi.hut.tcm.ECImplementation
  File:    LucasSequence.java
*/

package fi.hut.tcm.tessa.ECImplementation;
import java.math.BigInteger;

/**
  LucasSequence
  
  @doc
  A utility class used to calculate the lucas sequences required for
  the calculation of modulo square roots.
  
  @see ECUtilities
  
  @version 1.0, 30.3.1999
  @author Yki Kortesniemi 

*/
class LucasSequence
  extends Object {

  /**
  */
  private BigInteger U;
  
  /**
  */
  private BigInteger V;
  
  /**
  */
  static BigInteger TWO = new BigInteger("2");;
  
  /**
  */
  static BigInteger THREE = new BigInteger("3");;
  
  /**
  */
  static BigInteger FOUR = new BigInteger("4");;
  
  /**
  */
  static BigInteger FIVE = new BigInteger("5");;
  
  /**
  */
  static BigInteger EIGHT = new BigInteger("8");;
  
  /**
  */
  public static LucasSequence generate(BigInteger P, BigInteger B, BigInteger Q, BigInteger k) {
	BigInteger D = P.multiply(P).subtract(Q.multiply(FOUR));

	BigInteger U = BigInteger.ONE;
	BigInteger V = P;
	BigInteger tmp;
	int l = k.bitLength();
	for (int i = l-1; i >= 0; i--) {
		tmp = U.multiply(V).mod(P);
		V = V.multiply(V).add(D.multiply(U).multiply(U));
		V = V.divide(TWO).mod(P);
		U = tmp;

		if (k.testBit(i)) {
			tmp = P.multiply(U).add(V);
			tmp = tmp.divide(TWO).mod(P);
			V = P.multiply(V).add(D.multiply(U));
			V = V.divide(TWO).mod(P);
			U = tmp;
		}
	}
	return new LucasSequence(U, V);
  }
  
  /**
  */
  private LucasSequence(BigInteger U, BigInteger V) {
	this.U = U;
	this.V = V;
  }
  
  /**
  */
  public BigInteger getU() {
	return U;
  }
  
  /**
  */
  public BigInteger getV() {
	return V;
  }
  
} // LucasSequence
