/**
  Copyright (C) 2000 Helsinki University of Technology, Inc. All rights Reserved.
  XXX   %Z%%M% version %I% date:%G%
  Component:  ECDSAKey
  Package: fi.hut.tcm.ECInterfaces
  File:    ECDSAKey.java
*/

package fi.hut.tcm.tessa.ECInterfaces;
import java.math.BigInteger;


/**
  ECDSAKey
  
  @doc
  The interface to an ECDSA public or private key. ECDSA (Elliptic Curve 
  Digital Signature Algorithm) is defined in ANSI's X9.62 Standard (Draft).
  
  @see ECDSAParams
  @see java.security.Key
  @see java.security.Signature
  
  @version 1.0, 30.3.1999
  @author Yki Kortesniemi 
*/
public interface ECDSAKey {

  /**
    @doc
    Returns the ECDSA-specific key parameters. These parameters are
    never secret.
    
    @return the ECDSA-specific key parameters.
    
    @see ECDSAParams
  */
  public abstract ECDSAParams getParams();
  
} // ECDSAKey
