/**
  Copyright (C) 2000 Helsinki University of Technology, Inc. All rights Reserved.
  XXX   %Z%%M% version %I% date:%G%
  Component:  ECDSAParams
  Package: fi.hut.tcm.ECInterfaces
  File:    ECDSAParams.java
*/

package fi.hut.tcm.tessa.ECInterfaces;
import java.math.BigInteger;
import java.security.spec.*;

/**
  ECDSAParams
  
  @doc
  Interface to an ECDSA-specific set of key parameters, which defines an 
  ECDSA <em>key family</em>. ECDSA (Elliptic Curve Digital Signature Algorithm) is defined 
  in ANSI's X9.62 Standard (Draft).
  
  @see ECDSAKey
  @see java.security.Key
  @see java.security.Signature
  
  @version 1.0, 30.3.1999
  @author Yki Kortesniemi 
*/
public interface ECDSAParams
  extends AlgorithmParameterSpec {

  /**
    @doc
    Returns the prime field used, <code>p</code>.
    
    @return the prime field, <code>p</code>. 
  */
  public abstract BigInteger getP();
  
  /**
    @doc
    Returns the generator point, <code>G</code>.
    
    @return the generator point, <code>G</code>. 
  */
  public abstract ECPoint getG();
  
  /**
    @doc
    Returns the order of the generator point, <code>N</code>.
    
    @return the order of the generator point, <code>N</code>. 
  */
  public abstract BigInteger getN();
  
  /**
    @doc
    Returns the cofactor, <code>H</code>.
    
    @return the cofactor, <code>H</code>. 
  */
  public abstract BigInteger getH();
  
  /**
    @doc
    Returns the first curve parameter, <code>a</code>.
    
    @return the first curve parameter, <code>a</code>. 
  */
  public abstract BigInteger getA();
  
  /**
    @doc
    Returns the second curve parameter, <code>b</code>.
    
    @return the second curve parameter, <code>b</code>. 
  */
  public abstract BigInteger getB();
  
} // ECDSAParams
