/**
  Copyright (C) 2000 Helsinki University of Technology, Inc. All rights Reserved.
  XXX   %Z%%M% version %I% date:%G%
  Component:  ECDSAPrivateKey
  Package: fi.hut.tcm.ECInterfaces
  File:    ECDSAPrivateKey.java
*/

package fi.hut.tcm.tessa.ECInterfaces;
import java.math.BigInteger;


/**
  ECDSAPrivateKey
  
  @doc
  The standard interface to an ECDSA private key. ECDSA (Elliptic Curve Digital Signature
  Algorithm) is defined in ANSI's X9.62 Standard (Draft).
  
  @see java.security.Key
  @see java.security.Signature
  @see ECDSAKey
  @see ECDSAPublicKey
  
  @version 1.0, 30.3.1999
  @author Yki Kortesniemi 
*/
public interface ECDSAPrivateKey
  extends ECDSAKey {

  /**
    @doc
    Returns the value of the private key, <code>d</code>.
    
    @return the value of the private key, <code>d</code>. 
  */
  public abstract BigInteger getD();
  
  /**
    @doc
    Returns the ECDSA-specific key parameters. These parameters are
    never secret.
    
    @return the ECDSA-specific key parameters.
    
    @see ECDSAParams
  */
  public abstract ECDSAParams getParams();
  
} // ECDSAPrivateKey
