/**
  Copyright (C) 2000 Helsinki University of Technology, Inc. All rights Reserved.
  XXX   %Z%%M% version %I% date:%G%
  Component:  ECDSAPublicKey
  Package: fi.hut.tcm.ECInterfaces
  File:    ECDSAPublicKey.java
*/

package fi.hut.tcm.tessa.ECInterfaces;
import java.math.BigInteger;


/**
  ECDSAPublicKey
  
  @doc
  The interface to an ECDSA public key. ECDSA (Digital Signature Algorithm) 
  is defined in ANSI's X9.62 Standard (Draft).
  
  @see java.security.Key
  @see java.security.Signature
  @see ECDSAKey
  @see ECDSAPrivateKey
  
  @version 1.0, 30.3.1999
  @author Yki Kortesniemi 
*/
public interface ECDSAPublicKey
  extends ECDSAKey {

  /**
    @doc
    Returns the value of the public key, <code>Q</code>.
    
    @return the value of the public key, <code>Q</code>. 
  */
  public abstract ECPoint getQ();
  
  /**
    @doc
    Returns the ECDSA-specific key parameters. These parameters are
    never secret.
    
    @return the ECDSA-specific key parameters.
    
    @see ECDSAParams
  */
  public abstract ECDSAParams getParams();
  
} // ECDSAPublicKey

