/**
  Copyright (C) 2000 Helsinki University of Technology, Inc. All rights Reserved.
  XXX   %Z%%M% version %I% date:%G%
  Component:  ECPoint
  Package: fi.hut.tcm.ECInterfaces
  File:    ECPoint.java
*/

package fi.hut.tcm.tessa.ECInterfaces;
import java.math.BigInteger;

/**
  ECPoint
  
  @doc
  The interface to a point on an Elliptic Curve.
  
  @see ECDSAParams
  
  @version 1.0, 30.3.1999
  @author Yki Kortesniemi 
*/
public interface ECPoint {

  /**
    @doc
    Returns the x-coordinate of the point, <code>x</code>.
    
    @return the x-coordinate of the point, <code>x</code>. 
  */
  public abstract BigInteger getX();
  
  /**
    @doc
    Returns the y-coordinate of the point, <code>y</code>.
    
    @return the y-coordinate of the point, <code>y</code>. 
  */
  public abstract BigInteger getY();
  
  /**
    @doc
    Returns true, if the point is at infinity.
    
    @return true, if the point is at infinity. 
  */
  public abstract boolean isInfinity();
  
  /**
    @doc
    Returns the ECDSA-specific key parameters. These parameters are
    never secret.
    
    @return the ECDSA-specific key parameters.
    
    @see ECDSAParams
  */
  public abstract ECDSAParams getParams();
  
  /**
    @doc
    Returns the sum of this point and another point, <code>P</code>.
    
    @return the sum of this point and point <code>P</code>. 
  */
  public abstract ECPoint add(ECPoint P);
  
  /**
    @doc
    Returns the difference of this point and another point,, <code>p</code>.
    
    @return the difference of this point and point <code>p</code>. 
  */
  public abstract ECPoint subtract(ECPoint P);
  
  /**
    @doc
    Returns the product of this point and BigInteger <code>k</code>.
    
    @return the product of this point and BigInteger <code>k</code>. 
  */
  public abstract ECPoint multiply(BigInteger k);
  
  /**
    @doc
    Returns a clone of this object.
    
    @return a clone of this object. 
  */
  public abstract Object clone();
  
} // ECPoint
